Enum arrow_flight::sql::Nullable
source · #[repr(i32)]pub enum Nullable {
NullabilityNoNulls = 0,
NullabilityNullable = 1,
NullabilityUnknown = 2,
}Variants
NullabilityNoNulls = 0
Indicates that the fields does not allow the use of null values.
NullabilityNullable = 1
Indicates that the fields allow the use of null values.
NullabilityUnknown = 2
Indicates that nullability of the fields cannot be determined.
Implementations
sourceimpl Nullable
impl Nullable
sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.