Struct arrow_flight::sql::metadata::SqlInfoList
source · pub struct SqlInfoList { /* private fields */ }Expand description
A builder for CommandGetSqlInfo response.
CommandGetSqlInfo are metadata requests used by a Flight SQL
server to communicate supported capabilities to Flight SQL
clients.
Servers construct a SqlInfoList by adding infos via
with_sql_info and build the response using encode.
The available configuration options are defined in the Flight SQL protos.
Example
// Create the list of metadata describing the server
let info_list = SqlInfoList::new()
.with_sql_info(SqlInfo::FlightSqlServerName, "server name")
// ... add other SqlInfo here ..
.with_sql_info(
SqlInfo::FlightSqlServerTransaction,
SqlSupportedTransaction::Transaction as i32,
);
// Create the batch to send back to the client
let batch = info_list.encode().unwrap();Implementations
sourceimpl SqlInfoList
impl SqlInfoList
pub fn new() -> Self
sourcepub fn with_sql_info(
self,
name: impl SqlInfoName,
value: impl Into<SqlInfoValue>
) -> Self
pub fn with_sql_info( self, name: impl SqlInfoName, value: impl Into<SqlInfoValue> ) -> Self
register the specific sql metadata item
sourcepub fn filter(&self, info: &[u32]) -> Cow<'_, Self>
pub fn filter(&self, info: &[u32]) -> Cow<'_, Self>
Filter this info list keeping only the info values specified
in infos.
Returns self if infos is empty (no filtering)
sourcepub fn encode(&self) -> Result<RecordBatch>
pub fn encode(&self) -> Result<RecordBatch>
Encode the contents of this list according to the FlightSQL spec
sourcepub fn schema() -> &'static Schema
pub fn schema() -> &'static Schema
Return the Schema for a GetSchema RPC call with crate::sql::CommandGetSqlInfo